function [pCO2,fCO2] = TotCO2_FreeCO2_Inversion(TotCO2,pO2,pHrbc,DPGrbc,Temp,Hbrbc,Hct)

% Set the iteration parameters for computing pCO2 from TotCO2
iter_max = 50; % Maximum number of allowed iterations
err_tol = 1e-4; % Tolerance for convergence (this is set for pCO2)
err = 1; % Initial error, an arbitraty large number
iter = 0; % initialize the iter counter

% Compute alphaCO2 at given physiological conditions, and set initial guess for pCO2.
Input = [pO2,40,pHrbc,DPGrbc,Temp,Hbrbc,Hct];
[Output] = SHbO2CO2_EJAP2016(Input); alphaCO2 = Output{1}(2);
pCO2old = 40; % Initial guess for pCO2

% Newton-Raphson's iterative method for computation of pCO2 from TotCO2
while (iter < iter_max && err > err_tol)
    pCO2c = pCO2old;
    pCO2p = pCO2old + 1e-3*pCO2old;
    pCO2m = pCO2old - 1e-3*pCO2old;
    Inputc = [pO2,pCO2c,pHrbc,DPGrbc,Temp,Hbrbc,Hct];
    Inputp = [pO2,pCO2p,pHrbc,DPGrbc,Temp,Hbrbc,Hct];
    Inputm = [pO2,pCO2m,pHrbc,DPGrbc,Temp,Hbrbc,Hct];
    [Outputc] = SHbO2CO2_EJAP2016(Inputc); CO2totc = Outputc{2}(2);
    [Outputp] = SHbO2CO2_EJAP2016(Inputp); CO2totp = Outputp{2}(2);
    [Outputm] = SHbO2CO2_EJAP2016(Inputm); CO2totm = Outputm{2}(2);
    dCO2totc = (CO2totp-CO2totm)/(pCO2p-pCO2m);  % Derivative by central difference
    funcCO2 = TotCO2 - CO2totc; % Function to be solved (find pCO2 such that funcCO2 = 0) 
    dfuncCO2 = -dCO2totc; % As TotCO2 is an input (constant), dTotCO2 = 0
    pCO2new = pCO2old - funcCO2/dfuncCO2; % Newton-Raphson iterative folrmula
    iter = iter + 1;
    err = abs(pCO2new - pCO2old)/pCO2new;
    pCO2old = pCO2new;
end
pCO2 = pCO2new; fCO2 = alphaCO2*pCO2;
% tmp = [TotCO2,fCO2,pCO2,iter,err];
% disp('The values of TotCO2, FreeCO2, pCO2, iter, and error'); disp(tmp);
if (iter == iter_max)
    disp('The iteration scheme did not converge')
end
