function [pO2,fO2] = TotO2_FreeO2_Inversion(TotO2,pCO2,pHrbc,DPGrbc,Temp,Hbrbc,Hct)

% Set the iteration parameters for computing pO2 from TotO2
iter_max = 50; % Maximum number of allowed iterations
err_tol = 1e-4; % Tolerance for convergence (this is set for pO2)
err = 1; % Initial error, an arbitraty large number
iter = 0; % initialize the iter counter

% Compute P50O2 and alphaO2 at given physiological conditions, and set initial guess for pO2.
Input = [100,pCO2,pHrbc,DPGrbc,Temp,Hbrbc,Hct];
[Output] = SHbO2CO2_EJAP2016(Input); alphaO2 = Output{1}(1); P50 = Output{1}(3); 
pO2old = P50; % Inital guess for pO2 computation (good guess)

% Newton-Raphson's iterative method for computation of pO2 from TotO2
while (iter < iter_max && err > err_tol)
    pO2c = pO2old;
    pO2p = pO2old + 1e-2*pO2old;
    pO2m = pO2old - 1e-2*pO2old;
    Inputc = [pO2c,pCO2,pHrbc,DPGrbc,Temp,Hbrbc,Hct];
    Inputp = [pO2p,pCO2,pHrbc,DPGrbc,Temp,Hbrbc,Hct];
    Inputm = [pO2m,pCO2,pHrbc,DPGrbc,Temp,Hbrbc,Hct];
    [Outputc] = SHbO2CO2_EJAP2016(Inputc); O2totc = Outputc{2}(1);
    [Outputp] = SHbO2CO2_EJAP2016(Inputp); O2totp = Outputp{2}(1);
    [Outputm] = SHbO2CO2_EJAP2016(Inputm); O2totm = Outputm{2}(1);
    dO2totc = (O2totp-O2totm)/(pO2p-pO2m); % M/mmHg Derivative by central difference
    funcO2 = TotO2 - O2totc; % M Function to be solved (find pO2 such that funcO2 = 0) 
    dfuncO2 = -dO2totc; % M/mmHg As TotO2 is an input (constant), dTotO2 = 0
    pO2new = pO2old - funcO2/dfuncO2; % Newton-Raphson iterative folrmula
    iter = iter + 1;
    err = abs(pO2new - pO2old)/pO2new;
    pO2old = pO2new;
end
pO2 = pO2new; fO2 = alphaO2*pO2;
% tmp = [TotO2,fO2,pO2,iter,err];
% disp('The values of TotO2, fO2, pO2, iter, and error'); disp(tmp);
if (iter == iter_max)
    disp('The iteration scheme did not converge')
end
